"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const gensequence_1 = require("gensequence");
const HR = require("hunspell-reader");
const fs = require("fs-extra");
const cspell_trie_lib_1 = require("cspell-trie-lib");
const zlib = require("zlib");
const regHunspellFile = /\.(dic|aff)$/i;
// Readers first match wins
const readers = [
    { test: /\.trie\b/, method: iterateTrieFile },
    { test: regHunspellFile, method: readHunspellFiles },
];
async function readHunspellFiles(filename, options) {
    const dicFile = filename.replace(regHunspellFile, '.dic');
    const affFile = filename.replace(regHunspellFile, '.aff');
    const reader = await HR.IterableHunspellReader.createFromFiles(affFile, dicFile);
    reader.maxDepth = options.maxDepth !== undefined ? options.maxDepth : reader.maxDepth;
    return gensequence_1.genSequence(reader);
}
exports.readHunspellFiles = readHunspellFiles;
async function iterateTrieFile(filename) {
    const trieRoot = cspell_trie_lib_1.importTrie(await iterateFile(filename));
    const trie = new cspell_trie_lib_1.Trie(trieRoot);
    return trie.words();
}
async function iterateFile(filename) {
    const content = await fs.readFile(filename)
        .then(buffer => (/\.gz$/).test(filename) ? zlib.gunzipSync(buffer) : buffer)
        .then(buffer => buffer.toString('UTF-8'));
    return gensequence_1.genSequence(content.split('\n'));
}
function streamWordsFromFile(filename, options) {
    for (const reader of readers) {
        if (reader.test.test(filename)) {
            return reader.method(filename, options);
        }
    }
    return iterateFile(filename);
}
exports.streamWordsFromFile = streamWordsFromFile;
//# sourceMappingURL=iterateWordsFromFile.js.map